package com.siwei.rsmonitoring.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.siwei.common.core.utils.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.siwei.common.log.annotation.Log;
import com.siwei.common.log.enums.BusinessType;
import com.siwei.common.security.annotation.RequiresPermissions;
import com.siwei.rsmonitoring.domain.TDictData;
import com.siwei.rsmonitoring.service.ITDictDataService;
import com.siwei.common.core.web.controller.BaseController;
import com.siwei.common.core.web.domain.AjaxResult;
import com.siwei.common.core.utils.poi.ExcelUtil;

/**
 * 字段数据（树结构）Controller
 *
 * @author siwei
 * @date 2025-02-27
 */
@RestController
@RequestMapping("/dict_data")
public class TDictDataController extends BaseController {
    @Autowired
    private ITDictDataService tDictDataService;

    /**
     * 获取字段数据（树结构）详细信息
     */
//    @RequiresPermissions("rsmonitoring:data:tree")
    @GetMapping(value = "/tree")
    public AjaxResult getTree(String dictType, String parent) {
        if (StringUtils.isEmpty(dictType)) {
            return error("参数缺失");
        }
        if (StringUtils.isEmpty(parent)) {
            parent = "-999";
        }
        return success(tDictDataService.selectTDictDataTree(dictType, parent));
    }


//    /**
//     * 查询字段数据（树结构）列表
//     */
////    @RequiresPermissions("rsmonitoring:data:list")
//    @GetMapping("/list")
//    public AjaxResult list(TDictData tDictData)
//    {
//        List<TDictData> list = tDictDataService.selectTDictDataList(tDictData);
//        return success(list);
//    }
//
//    /**
//     * 导出字段数据（树结构）列表
//     */
////    @RequiresPermissions("rsmonitoring:data:export")
//    @Log(title = "字段数据（树结构）", businessType = BusinessType.EXPORT)
//    @PostMapping("/export")
//    public void export(HttpServletResponse response, TDictData tDictData)
//    {
//        List<TDictData> list = tDictDataService.selectTDictDataList(tDictData);
//        ExcelUtil<TDictData> util = new ExcelUtil<TDictData>(TDictData.class);
//        util.exportExcel(response, list, "字段数据（树结构）数据");
//    }
//
//    /**
//     * 获取字段数据（树结构）详细信息
//     */
////    @RequiresPermissions("rsmonitoring:data:query")
//    @GetMapping(value = "/{dictCode}")
//    public AjaxResult getInfo(@PathVariable("dictCode") Long dictCode)
//    {
//        return success(tDictDataService.selectTDictDataByDictCode(dictCode));
//    }
//
//    /**
//     * 新增字段数据（树结构）
//     */
////    @RequiresPermissions("rsmonitoring:data:add")
//    @Log(title = "字段数据（树结构）", businessType = BusinessType.INSERT)
//    @PostMapping
//    public AjaxResult add(@RequestBody TDictData tDictData)
//    {
//        return toAjax(tDictDataService.insertTDictData(tDictData));
//    }
//
//    /**
//     * 修改字段数据（树结构）
//     */
////    @RequiresPermissions("rsmonitoring:data:edit")
//    @Log(title = "字段数据（树结构）", businessType = BusinessType.UPDATE)
//    @PutMapping
//    public AjaxResult edit(@RequestBody TDictData tDictData)
//    {
//        return toAjax(tDictDataService.updateTDictData(tDictData));
//    }
//
//    /**
//     * 删除字段数据（树结构）
//     */
////    @RequiresPermissions("rsmonitoring:data:remove")
//    @Log(title = "字段数据（树结构）", businessType = BusinessType.DELETE)
//	@DeleteMapping("/{dictCodes}")
//    public AjaxResult remove(@PathVariable Long[] dictCodes)
//    {
//        return toAjax(tDictDataService.deleteTDictDataByDictCodes(dictCodes));
//    }
}
